%function estabilshing FE-model (stiffness, damping and intertia)
function [Ksys,Csys,Msys,Ksys_initial,Csys_initial] = ...
FE_model(EI,l,T,m,n,n_dof,alpha1,alpha2)

%element matrices:

%bending stiffness
Ke = EI*[12/(l^3) -6/(l^2) -12/(l^3) -6/(l^2);
        -6/(l^2)  4/l       6/(l^2)  2/l;
       -12/(l^3)  6/(l^2)  12/(l^3)  6/(l^2);
        -6/(l^2)  2/l       6/(l^2)  4/l];

% geometric stiffness
Kg = T*[6/(5*l) -1/10  -6/(5*l) -1/10;
      -1/10    2*l/15 1/10    -l/30;
      -6/(5*l) 1/10   6/(5*l)  1/10;
      -1/10   -l/30   1/10     2*l/15];

K = Ke + Kg;

%mass matrix
M = m*l/420*[156  -22*l   54    13*l;
           -22*l  4*l^2 -13*l -3*l^2;
           54     -13*l  156   22*l;
           13*l  -3*l^2  22*l  4*l^2];

%system matrices
Ksys = zeros(n_dof);
Msys = zeros(n_dof);

%Assemble system matrices
for i = 1 : n         
    j = 2*i - 2;
    for x = 1 : 4
        for y = 1 : 4
            Ksys(j+x,j+y) = Ksys(j+x,j+y)+K(x,y);
            Msys(j+x,j+y) = Msys(j+x,j+y)+M(x,y);
        end
    end
end

%introduce BCs
Ksys(1,:) = [];
Ksys(:,1) = [];
Msys(1,:) = [];
Msys(:,1) = [];

Ksys(n_dof-2,:) = [];
Ksys(:,n_dof-2) = [];
Msys(n_dof-2,:) = [];
Msys(:,n_dof-2) = [];

%damping matrix                     
Csys = alpha1*Msys+alpha2*Ksys;

%% Initial stiffness and damping used in non-linear analysis
Ksys_initial = Ksys;
Csys_initial = Csys;