%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                  % 
% code name:                       %
% ULVESETER'S MODEL                %
%                                  %     
% Based on Thorsen's VIV model     %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

clear all
close all
clc

%% Input options %%
%%%%%%%%%%%%%%%%%%%
text1 = 'Choose Case 1,2,3,4,5,6 or 7: ';
text2 = 'Choose linear analysis (1) or nonlinear analysis (2): ';
Case = input(text1);
type = input(text2);

%% Input parameters %%
%%%%%%%%%%%%%%%%%%%%%%
[D,L,EI,E,T,U,mdry,rho_sw,Ca,alpha1,alpha2,k_s,c_s,n,g,Tsim,h,m,l,n_dof,...
n_dof_red,n_nodes,transdofs,gamma,beta] = input_parameters(Case);

%% Inputs from RIFLEX %%
%%%%%%%%%%%%%%%%%%%%%%%%
[seabed_VIVANA, static_config, free_span_length,sea_bottom,static_gap] = ...
RIFLEX_input(Case,l,D,n_nodes,L);

%% Establishing FE model %%
%%%%%%%%%%%%%%%%%%%%%%%%%%%
[Ksys,Csys,Msys,Ksys_initial,Csys_initial] = ...
FE_model(EI,l,T,m,n,n_dof,alpha1,alpha2);

%% Eigenfrequencies %%
%%%%%%%%%%%%%%%%%%%%%%
MATLAB_f0_initial = (1/(2*pi)) * sqrt(eig(Ksys,Msys));

%% LINEAR ANALYSIS BEGINS %%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if type == 1
    
    %linear analysis
    [y,ytrans,dy,dytrans,ddy,ddytrans,phi_exc,Qy,Qytrans,time,Ay0,Ay1,...
    dymax,ddymax,N,MATLAB_f0] = linear_analysis(Ksys,Msys,Csys,k_s,c_s,...
    sea_bottom,transdofs,gamma,beta,h,rho_sw,D,l,Tsim,U,static_gap);

%% NONLINEAR ANALYSIS BEGINS %%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
elseif type == 2

    %nonlinear analysis
    [y,ytrans,dy,dytrans,ddy,ddytrans,phi_exc,Qy,Qytrans,time,Ay0,Ay1,...
    dymax,ddymax,N] = nonlinear_analysis(Ksys_initial,...
    Csys_initial,Ksys,Msys,Csys,k_s,c_s,sea_bottom,transdofs,gamma,beta,h,...
    rho_sw,D,l,Tsim,U,static_gap,static_config,mdry,seabed_VIVANA,n,g);

end %if type

%% Post-processing %
%%%%%%%%%%%%%%%%%%%%
[stress_amp, stress_rms,stress_std,fp] = POSTproc(ytrans,l,L,D,E,N,n,h,...
Tsim,c_s,k_s,type,sea_bottom,seabed_VIVANA,static_config,Case);

