%input parameters

function [D,L,EI,E,T,U,mdry,rho_sw,Ca,alpha1,alpha2,k_s,c_s,n,g,Tsim,h,m,...
l,n_dof,n_dof_red,n_nodes,transdofs,gamma,beta] = input_parameters(Case)


if Case == 1 %Pipeline data for same model as used in my Project Thesis

%Physical:
A_int   = 0.1018;               %[m^2]      internal area
A_ext   = 0.1256;               %[m^2]      total area 
D       = 2 * sqrt(A_ext/pi);   %[m]        external diameter
L       = 180;                  %[m]        model length   
EI      = 8.9*10^7;             %[Nm^2]     bending stiffness
E       = 207*10^9;             %[N/m^2]    E-module (steel, used in VIVANA) 
T       = 10*10^3;              %[N]        tension (STAMOD CALLAS)
U       = 1.2;                  %[m/s]      incoming current velocity
mdry    = 217.96;               %[kg/m]     mass per unit length, dry
rho_sw  = 1027;                 %[kg/m^3]   density of water
Ca      = 1.0;                  %[-]        added mass coefficient
alpha1  = 0;                    %           proportional damping factor 1
alpha2  = 0;                    %           proportional damping factor 2
k_s     = 17460.105;            %[N/m^2]    vertical soil_stiffness per meter
c_s     = 492.25;               %[Ns/m^2]   vertical soil damping per meter 
n       = 180;                  %[-]        number of elements

elseif Case == 2 || Case == 3 %% model used in omae2004

%Physical:
D       = 0.55;                 %[m]        external diameter
L       = 380;                  %[m]        model length
EI      = 2.9*10^8;             %[Nm^2]     bending stiffness
E       = 208*10^9;             %[N/m^2]    E-module (steel) 
T       = 450*10^3;             %[N]        tension
U       = 0.7;                  %[m/s]      incoming current velocity
mdry    = 315;                  %[kg/m]     mass per unit length, dry
rho_sw  = 1025;                 %[kg/m^3]   density of water
Ca      = 1.0;                  %[-]        added mass coefficient
alpha1  = 0;                    %           proportional damping factor 1
alpha2  = 0;                    %           proportional damping factor 2
k_s     = 40*10^3;              %[N/m^2]    vertical soil_stiffness per meter
c_s     = 945.32;               %[Ns/m^2]   vertical soil damping per meter 
n       = 380;                  %[-]        number of elements 

elseif Case == 4 %% model used for comparison to time domain analysis
%Physical:
D       = 0.556;                %[m]        external diameter
L       = 380;                  %[m]        model length
EI      = 2.93*10^7;            %[Nm^2]     bending stiffness
E       = 20.6*10^9;            %[N/m^2]    E-module (steel) 
T       = 450*10^3;             %[N]        tension
U       = 0.7;                  %[m/s]      incoming current velocity
mdry    = 315;                  %[kg/m]     mass per unit length, dry
rho_sw  = 1025;                 %[kg/m^3]   density of water
Ca      = 1.0;                  %[-]        added mass coefficient
alpha1  = 0;                    %           proportional damping factor 1
alpha2  = 0;                    %           proportional damping factor 2
k_s     = 40*10^3;              %[N/m^2]    vertical soil_stiffness per meter
c_s     = 954.11;               %[Ns/m^2]   vertical soil damping per meter 
n       = 380;                  %[-]        number of elements 

elseif Case == 5 %% model used in omae2004, with varying current speed

%Physical:
D       = 0.55;                 %[m]        external diameter
L       = 380;                  %[m]        model length
EI      = 2.9*10^8;             %[Nm^2]     bending stiffness
E       = 208*10^9;             %[N/m^2]    E-module (steel) 
T       = 450*10^3;             %[N]        tension
U       = 1.1;                  %[m/s]      incoming current velocity
mdry    = 315;                  %[kg/m]     mass per unit length, dry
rho_sw  = 1025;                 %[kg/m^3]   density of water
Ca      = 1.0;                  %[-]        added mass coefficient
alpha1  = 0;                    %           proportional damping factor 1
alpha2  = 0;                    %           proportional damping factor 2
k_s     = 40*10^3;              %[N/m^2]    vertical soil_stiffness per meter
c_s     = 945.32;               %[Ns/m^2]   vertical soil damping per meter 
n       = 380;                  %[-]        number of elements 

elseif Case == 6 %% model used in omae2004, hard bottom case

%Physical:
D       = 0.55;                 %[m]        external diameter
L       = 380;                  %[m]        model length
EI      = 2.9*10^8;             %[Nm^2]     bending stiffness
E       = 208*10^9;             %[N/m^2]    E-module (steel) 
T       = 450*10^3;             %[N]        tension
U       = 0.7;                  %[m/s]      incoming current velocity
mdry    = 315;                  %[kg/m]     mass per unit length, dry
rho_sw  = 1025;                 %[kg/m^3]   density of water
Ca      = 1.0;                  %[-]        added mass coefficient
alpha1  = 0;                    %           proportional damping factor 1
alpha2  = 0;                    %           proportional damping factor 2
k_s     = 80*10^3;              %[N/m^2]    vertical soil_stiffness per meter
c_s     = 945.32;               %[Ns/m^2]   vertical soil damping per meter 
n       = 380;                  %[-]        number of elements 

elseif Case == 7 %% model used in omae2004, soft bottom case

%Physical:
D       = 0.55;                 %[m]        external diameter
L       = 380;                  %[m]        model length
EI      = 2.9*10^8;             %[Nm^2]     bending stiffness
E       = 208*10^9;             %[N/m^2]    E-module (steel) 
T       = 450*10^3;             %[N]        tension
U       = 0.7;                  %[m/s]      incoming current velocity
mdry    = 315;                  %[kg/m]     mass per unit length, dry
rho_sw  = 1025;                 %[kg/m^3]   density of water
Ca      = 1.0;                  %[-]        added mass coefficient
alpha1  = 0;                    %           proportional damping factor 1
alpha2  = 0;                    %           proportional damping factor 2
k_s     = 10199.187;            %[N/m^2]    vertical soil_stiffness per meter
c_s     = 945.32;               %[Ns/m^2]   vertical soil damping per meter 
n       = 380;                  %[-]        number of elements 
end
g       = 9.81;                 %[m/s^2]    acceleration of gravity
%% Numerical input

Tsim    = 150;      % simulation time
h       = 0.01;     % time step size 
%n       = 180;     % number of elements
gamma   = 0.5;      % Newmark parameter
beta    = 0.25;     % Newmark parameter
    
m           = mdry+Ca*rho_sw*pi/4*D^2;  %mass + added mass per unit length
l           = L/n;                      %length of each element
n_dof       = (n+1)*2;                  %mumber of dofs
n_dof_red   = n_dof - 2;                %reduced number of dofs after BCs 
n_nodes     = n + 1;                    %number of nodes
transdofs   = [2:2:2*n-1];              %id translation dofs, reduced set