%linear time domain procedure 
function [y,ytrans,dy,dytrans,ddy,ddytrans,phi_exc,Qy,Qytrans,time,Ay0,Ay1...
,dymax,ddymax,N] = linear_time_domain(Tsim,h,transdofs,Ksys,U,rho_sw,D,l,beta,...
gamma,Msys,Csys,Khatinv,static_gap)

N=ceil(Tsim/h); %number of time steps

%preallocate space
y=zeros(size(Ksys,1),N);
ytrans=zeros(length(transdofs),N);              %translation
dy=zeros(size(Ksys,1),N);
dytrans=zeros(length(transdofs),N);             %translation velocity
ddy=zeros(size(Ksys,1),N);
ddytrans=zeros(length(transdofs),N);            %translation acceleration
phi_exc=zeros(length(transdofs),N);             %(only for translation dofs)
phi_exc(:,1)=2*pi*rand(length(transdofs),1);    %random phase angle 
Qy=zeros(size(Ksys,1),N);                       
Qytrans=zeros(length(transdofs),N);
time=h*[0:N];
Ay0=zeros(length(transdofs),1);                 
Ay1=zeros(length(transdofs),1);                 
dymax=zeros(length(transdofs),1);              
ddymax=zeros(length(transdofs),1);            

Ui=0;           %start with zero current speed
nramp=0.1*N;    %use 10 % of sim time to ramp up current velocity
for i=1:N
    if i>nramp
        Ui=U;
    else
        Ui=Ui+U/nramp;   %ramping up current speed
    end

    %External (hydrodynamic) forces
    [Qytrans(:,i+1), phi_exc(:,i+1)] = hydroforce(h, rho_sw,...
    U*ones(length(transdofs),1), D, Ay0, dytrans(:,i), dymax, ddytrans(:,i),...
    ddymax, phi_exc(:,i));  
    Qytrans(:,i+1)=Qytrans(:,i+1)*l;                
    
    %putting in zero values at moment dofs
    for k = 1 : length(transdofs)
        
    Qy(transdofs(k),i+1) = Qytrans(k,i+1);    
        
    end
    
    %hydrodynamic force initially at seabottom equal to zero 
    [Qytrans(:,i+1)] = hydro_force_soil(Qytrans(:,i+1),static_gap);
    
     %% Initial conditions to use in linear Newmark-beta integration
     y0      = y(:,i);
     dy0     = dy(:,i);
     ddy0    = ddy(:,i); 
     Qy1     = Qy(:,i+1);
        
     [y1, dy1, ddy1] = linear_newmark_beta(beta,gamma,h,Msys,Csys,Khatinv,...
     i,y0,dy0,ddy0,Qy1);
        
     %displacement, velocity and acceleration assigned to the matrices
     y(:,i+1)        = y1;
     dy(:,i+1)       = dy1;
     ddy(:,i+1)      = ddy1;
        
     %extract translations 
     ytrans(:,i+1) = y(transdofs,i+1);
     dytrans(:,i+1) = dy(transdofs,i+1);
     ddytrans(:,i+1) = ddy(transdofs,i+1); 

    %check for new value of maxima:                                  
    ind3=find(abs(dytrans(:,i)>dymax));
    for j=ind3
        dymax(j)=abs(dytrans(j,i));
    end
    ind4=find(abs(ddytrans(:,i)>ddymax));                               
    for j=ind4
        ddymax(j)=abs(ddytrans(j,i));
    end

    %check for zero-crossing (y)                      
    
    indx1=find(dytrans(:,i).*dytrans(:,i+1) < 0);
    %if zero crossing, store current amplitude, and start over
    for j=indx1
%         Ay0(j)=Ay1(j);
%         Ay0(j)=0.5*(Ay0(j)+Ay1(j)); %average
        Ay0(j)=0.9*Ay0(j)+0.1*Ay1(j); %weighted average
        Ay1(j)=0.5*abs(dytrans(j,i+1))*h;
    end
    indx2=find(dytrans(:,i).*dytrans(:,i+1) > 0);
    %if no zero crossing, continue integration
    for j=indx2
        Ay1(j)=Ay1(j)+0.5*abs(dytrans(j,i+1))*h;
    end
end
end