%nonlinear analysis 
function [y,ytrans,dy,dytrans,ddy,ddytrans,phi_exc,Qy,Qytrans,time,Ay0,Ay1,...
dymax,ddymax,N] = nonlinear_analysis(Ksys_initial,...
Csys_initial,Ksys,Msys,Csys,k_s,c_s,sea_bottom,transdofs,gamma,beta,h,rho_sw,...
D,l,Tsim,U,static_gap,static_config,mdry,seabed_VIVANA,n,g)
    %% Time domain analysis begins 
    
    N=ceil(Tsim/h); %number of time steps

    %preallocate space
    y=zeros(size(Ksys,1),N);
    ytrans=zeros(length(transdofs),N);              %translation
    dy=zeros(size(Ksys,1),N);
    dytrans=zeros(length(transdofs),N);             %translation velocity
    ddy=zeros(size(Ksys,1),N);
    ddytrans=zeros(length(transdofs),N);            %translation acceleration
    phi_exc=zeros(length(transdofs),N);   
    phi_exc(:,1)=2*pi*rand(length(transdofs),1);    %random phase anlge 
    Qy=zeros(size(Ksys,1),N);                       
    Qytrans=zeros(length(transdofs),N);
    time=h*[0:N];
    Ay0=zeros(length(transdofs),1);                
    Ay1=zeros(length(transdofs),1);                 
    dymax=zeros(length(transdofs),1);               
    ddymax=zeros(length(transdofs),1);              

    Ui=0;           %start with zero current speed
    nramp=0.1*N;    %use 10 % of sim time to ramp up current velocity
    for k=1:N
        if k>nramp
            Ui=U;
        else
            Ui=Ui+U/nramp;   %ramping up current speed
        end
        
        %% nonlinear stiffness and damping matrix due to varying contact... 
        %between pipe and soil bottom
        [Ksys, Csys, k_soil] = nonlinear_soil(Ksys_initial,Csys_initial,...
        ytrans,static_config,seabed_VIVANA,k,n,c_s,k_s,transdofs,l,D,rho_sw,...
        mdry,g);
       
        %% External (hydrodynamic) forces
        [Qytrans(:,k+1), phi_exc(:,k+1)] = hydroforce(h, rho_sw, ...
        U*ones(length(transdofs),1), D, Ay0, dytrans(:,k), dymax, ...
        ddytrans(:,k),ddymax, phi_exc(:,k));  
        Qytrans(:,k+1)=Qytrans(:,k+1)*l; 
        
        %hydrodynamic force initially at seabootom equal to zero 
        [Qytrans(:,k+1)] = hydro_force_soil(Qytrans(:,k+1),static_gap);

        %putting in zero values at moment dofs
        for p = 1 : length(transdofs)
            Qy(transdofs(p),k+1) = Qytrans(p,k+1);    
        end
        
        %% Initial conditions to use in nonlinear Newmark-beta integration
        y0      = y(:,k);
        dy0     = dy(:,k);
        ddy0    = ddy(:,k); 
        Qy1     = Qy(:,k+1);
     
        %% Nonlinear Newmark-beta time integration  
        [y1, dy1, ddy1] = nonlinear_newmark_beta(gamma,beta,h,Msys,Ksys,...
        Csys,k,y0,dy0,ddy0,Qy1);
        
        % displacement, velocity and acceleration assigned to the matrices
        y(:,k+1)        = y1;
        dy(:,k+1)       = dy1;
        ddy(:,k+1)      = ddy1;
        
        %extract translations 
        ytrans(:,k+1) = y(transdofs,k+1);
        dytrans(:,k+1) = dy(transdofs,k+1);
        ddytrans(:,k+1) = ddy(transdofs,k+1);
        
        %%     
        %check for new value of maxima:                                      
        ind3=find(abs(dytrans(:,k)>dymax)); 
        for j=ind3
            dymax(j)=abs(dytrans(j,k));
        end
        ind4=find(abs(ddytrans(:,k)>ddymax));                             
        for j=ind4
            ddymax(j)=abs(ddytrans(j,k));
        end

        %check for zero-crossing (y)                      
    
        indx1=find(dytrans(:,k).*dytrans(:,k+1) < 0);
        %if zero crossing, store current amplitude, and start over
        for j=indx1
%         Ay0(j)=Ay1(j);
%         Ay0(j)=0.5*(Ay0(j)+Ay1(j)); %average
            Ay0(j)=0.9*Ay0(j)+0.1*Ay1(j); %weighted average
            Ay1(j)=0.5*abs(dytrans(j,k+1))*h;
        end
        indx2=find(dytrans(:,k).*dytrans(:,k+1) > 0);
        %if no zero crossing, continue integration
        for j=indx2
            Ay1(j)=Ay1(j)+0.5*abs(dytrans(j,k+1))*h;
        end  
    
    end
    
end