%Nonlinear Newmark-beta integration, based on procedure in Dynamic analysis
%compendium 
function [y1, dy1, ddy1] = nonlinear_newmark_beta(gamma,beta,h,Msys,Ksys,Csys...
,k,y0,dy0,ddy0,Qy1)
%% Initial calculations

a1 = gamma/(beta*h);
a2 = 1/(beta*h^2);          
a3 = 1/(beta*h);
a4 = (1/(2*beta)) - 1;
a5 = gamma/beta;
a6 = ( (gamma/(2*beta)) - 1)/h;
a7 = a5 - 1;
a8 = (1 - gamma)*h;
a9 = gamma*h;

%mass contribution to effective stiffness
M_hat = a2*Msys;

%% For each time step

ak = a3*dy0 + a4*ddy0;
bk = a5*dy0 + a6*ddy0;

K_hat = Ksys + a1*Csys + M_hat;
deltaQ_hat = Qy1 + Csys*bk + Msys*ak - Csys*dy0 - Ksys*y0;

%% Solve wrt displacement increment 

%inverting K_hat 
K_hat_inv = K_hat\eye(size(K_hat));

%displacement increment 
delta_y = K_hat_inv*deltaQ_hat;

%% acceleration, velocity and displacement at time i+1

ddy1  = a2*delta_y - ak;
dy1   = dy0 + a8*ddy0 + a9*ddy1;
y1    = y0 + delta_y;

end