%nonlinear stiffness matrix and damping matrix 
function [Ksys, Csys,k_soil,c_soil] = nonlinear_soil(Ksys_initial,Csys_initial...
,ytrans,static_config,seabed_VIVANA,time_step,num_elements,c_s,k_s,...
transdofs_id,elem_length,D,rho_sw,mdry,g)

%submerged weight per meter [N/m]
w_s = (mdry - pi*((D^2)/4)*rho_sw)*g;

%function finding the node number of the two nodes on each side which are
%closest to the free span
[left_side_node, right_side_node] = last_penetration_node(static_config,...
seabed_VIVANA,transdofs_id);

%defining size of soil stiffness matrix and put equal to zero for each
%time-step
k_soil = zeros(size(Ksys_initial));
c_soil = zeros(size(Csys_initial));

if num_elements + 1 ~= length(seabed_VIVANA(:,1))
    
    disp('number of elements do not match VIVANA results');
    
else
    
    for count = 1:length(transdofs_id) %do not look at first and last node 
        
        %section 1: the pipe is initially penetrating the seabed, so we can
        %have tensioning in the soil springs 
        if static_config(count+1,2) - seabed_VIVANA(count+1,2) < 0 &&...
           (count ~= left_side_node && count ~=right_side_node)
            
            if ytrans(count,time_step) + static_config(count+1,2) - ...
               seabed_VIVANA(count+1,2) < (w_s/k_s)
                
                k_soil(2*count,2*count) = k_s*elem_length;
                c_soil(2*count,2*count) = c_s*elem_length;
                
            end
        
        %section 2: the last nodes on each side with initial pipe penetration
        %can have 0.5*tension in the soil springs     
        elseif count == left_side_node || count == right_side_node 
            
            if ytrans(count,time_step) + static_config(count+1,2) - ...
               seabed_VIVANA(count+1,2) < 0.5*(w_s/k_s) 
                
                k_soil(2*count,2*count) = k_s*elem_length;
                c_soil(2*count,2*count) = c_s*elem_length;
                
            end
        
        %case 3: nodes in the inital free span can not have tension in the 
        %soil springs    
        elseif static_config(count+1,2) - seabed_VIVANA(count+1,2) > 0
            
            if ytrans(count,time_step) + static_config(count+1,2) - ...
               seabed_VIVANA(count+1,2) < 0 
                
                k_soil(2*count,2*count) = k_s*elem_length;
                c_soil(2*count,2*count) = c_s*elem_length;
                
            end
            
        end
            
     end
        
end 

Ksys = Ksys_initial + k_soil; 
Csys = Csys_initial + c_soil; 

end
