%post-processing creating plots
function post = plots(n,N,ytrans,stress_amp,stress_rms,stress_std,l,L,D,...
sea_bottom,seabed,static_config,c_s,Case,type,k_s)
%% plot/animation of response

%updating y_trans including zero at ends (for plotting) 
y_plot              = zeros(n+1,N+1);
y_plot(1,:)         = 0;
y_plot(n+1,:)       = 0;
y_plot(2:n,:)       = ytrans(:,:);

%% animation of response shapes 

% figure;
% for i = ceil(0.9*N):N
%     plot(y_plot(:,i),[0:l:L]);
%     xlim([-2*D 2*D]);
%     title('VIV Response');
%     xlabel('displacement [m]');
%     ylabel('length of structure [m]');
%     grid on
%     F(i) = getframe;   
% end
% 
% fps = 100;          %frames per second 
% num = 2;            %number of times to play the animation 

%% Snapshots of response curves

dN = 30; %number of time steps between each response 

figure;

for i = ceil(0.9*N) : dN : (N+1)
    
    hold on;
    plot([0:l:L],y_plot(:,i));
    title('Snapshots of response amplitudes');
    xlabel('z (m)');
    ylabel('y (m)');
    grid on; 
    
end

%% Snapshots of response curves + seabed

dN = 50; %number of time steps between each response 

figure;

for i = ceil(0.9*N) : dN : (N+1)
    
    hold on;
    plot([0:l:L],y_plot(:,i) + static_config(:,2));
    title('Snapshots of response amplitudes relative to seabed');
    xlabel('z (m)');
    ylabel('y (m)');
    ylim([-1010 -990]);
    xlim([0 L]);
    grid on; 
    
end

hold on;
%plot([0:l:L],seabed(:,2),'k','lineWidth',2);
area(seabed(:,2),-1010);
grid on;

%% plot of maximum response amplitude 

k = 0;
for i = ceil(0.9*N):N+1
    
    k = k + 1;
    
    val(k) = max(abs(y_plot(:,i)));
    
    [val2 indx] = max(val);
                  
end

tot_indx = indx + ceil(0.9*N)-1;

figure;
plot([0:l:L],abs(y_plot(:,tot_indx)));
xlabel('z (m)');
ylabel('y (m)');
title('Maximum response amplitude');
grid on;

%% plot of maximum response amplitude compared to VIVANA and to
%linear/nonlinear model 

if Case == 1
    %OBS! works only for 180 elements
    Mat = load('project_thesis\response_amplitudes_CF_VIVANA.txt');
    L_VIVANA = Mat(:,1);
    amp_VIVANA = Mat(:,2);
    figure;
    plot([0:l:L],abs(y_plot(:,indx + ceil(0.9*N)-1)),L_VIVANA,amp_VIVANA);
    grid on
    title('VIV response amplitudes');
    legend('Ulveseter linear model','VIVANA');
    xlabel('z [m]');
    ylabel('y [m]');
elseif Case == 2
    %OBS! works only for 380 elements
    Mat = load('omae2004\response_amplitudes_CF_VIVANA_omae04.txt');
    L_VIVANA = Mat(:,1);
    amp_VIVANA = Mat(:,2);
    figure;
    plot([0:l:L],abs(y_plot(:,indx + ceil(0.9*N)-1)),L_VIVANA,amp_VIVANA);
    grid on
    title('VIV response amplitudes');
    legend('Ulveseter linear model','VIVANA');
    xlabel('z [m]');
    ylabel('y [m]');
end


%% plot of stress amplitude if c_s = 0 
%%% LINEAR SOLUTION %%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if c_s == 0 && type == 1
figure;
plot([0:l:L-2*l],10^-6*stress_amp);
grid on;
xlabel('length of structure [m]');
ylabel('\sigma [MPa]');
title('VIV Stress amplitdes');
end

%% plot of stress amplitude for Thorsen and VIVANA
 
if c_s == 0 && type == 1
    
    if Case == 1
        %OBS! only for 180 elements
        Mat = load('project_thesis\stress_amplitudes_VIVANA.txt'); 
        
        L_VIVANA = Mat(1:length(Mat(:,1))-2,1);
        stress_amp_VIVANA = Mat(1:length(Mat(:,1))-2,2);
        figure; 
        plot([0:l:L-2*l],10^-6*...
        load('postproc\stress_amp_zero_damping_lin.txt'),L_VIVANA,...
        stress_amp_VIVANA);
        grid on;
        legend('Ulveseter linear model','VIVANA');
        title('VIV stress amplitudes');
        xlabel('z [m]');
        ylabel('\sigma [MPa]');
    elseif Case == 2 
        %OBS! only for 381 elements
        Mat = load('omae2004\stress_amplitudes_VIVANA_omae04.txt');
        L_VIVANA = Mat(1:length(Mat(:,1))-2,1);
        stress_amp_VIVANA = Mat(1:length(Mat(:,1))-2,2);
        figure; 
        plot([0:l:L-2*l],10^-6*...
        load('case2\linear\stress_amp_zero_damping_lin.txt'),L_VIVANA,...
        stress_amp_VIVANA*10^-3);
        grid on;
        legend('Ulveseter linear model','VIVANA');
        title('VIV stress amplitudes');
        xlabel('z [m]');
        ylabel('\sigma [MPa]');
    end
       
end




%% plot of stress amplitude if c_s = 0 
%%% NONLINEAR SOLUTION %%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if c_s == 0 && type == 2
figure;
plot([0:l:L-2*l],10^-6*stress_amp);
grid on;
xlabel('length of structure [m]');
ylabel('\sigma [MPa]');
title('VIV Stress amplitudes, nonlinear');
end

%% plot of stress amplitude for Thorsen and VIVANA
 
if c_s == 0 && type == 2
    
    if Case == 1
        %OBS! only for 180 elements
        Mat = load('project_thesis\stress_amplitudes_VIVANA.txt'); 
        L_VIVANA = Mat(1:length(Mat(:,1))-2,1);
        stress_amp_VIVANA = Mat(1:length(Mat(:,1))-2,2);
        figure; 
        plot([0:l:L-2*l],10^-6*load...
        ('postproc\stress_amp_zero_damping_nonlin.txt'),L_VIVANA,...
        stress_amp_VIVANA);
        grid on;
        legend('soil damping = 0, Thorsen','stress amplitudes VIVANA');
        title('VIV stress amplitudes, nonlinear');
        xlabel('z [m]');
        ylabel('\sigma [MPa]');
    elseif Case == 2 
        %OBS! only for 381 elements
        Mat = load('omae2004\stress_amplitudes_VIVANA_omae04.txt');
        L_VIVANA = Mat(1:length(Mat(:,1))-2,1);
        stress_amp_VIVANA = Mat(1:length(Mat(:,1))-2,2);
        figure; 
        plot([0:l:L-2*l],10^-6*load...
        ('case2\nonlinear\stress_amp_zero_damping_nonlin.txt'),L_VIVANA,...
        stress_amp_VIVANA);
        grid on;
        legend('soil damping = 0, Thorsen','stress amplitudes VIVANA');
        title('VIV stress amplitudes, nonlinear');
        xlabel('z [m]');
        ylabel('\sigma [MPa]');
    end
    
end

%% COMPARISON BETWEEN LINEAR AND NONLINER SOLUTION %%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

if Case == 1
figure;
plot([0:l:L-2*l],10^-6*load('postproc\stress_amp_nonzero_damping_lin.txt'),...
[0:l:L-2*l],10^-6*load('postproc\stress_amp_nonzero_damping_nonlin.txt'));
legend(['linear case, soil damping = ' num2str(c_s)],...
['nonlinear case, soil damping = ' num2str(c_s)]);
grid on;
title('VIV stress amplitudes');
xlabel('z [m]');
ylabel('\sigma [MPa]');
end


%% plot rms of stress-envelope

figure;
plot([0:l:L-2*l],10^-6*stress_rms,[0:l:L-2*l],10^-6*stress_std);
legend('stress rms','stress std');
grid on;
xlabel('length of structure [m]');
ylabel('stress amplitude [MPa]');
title('VIV Stress Response');


%% plot seabed

% figure;
% plot(sea_bottom(:,2),sea_bottom(:,1));
% grid on;
% xlabel('z [m]');
% ylabel('y [m]');
% title('Geometry of seabottom');
% ylim([-10 10]);

%% plot seabed from VIVANA-analysis in project work + static config

figure;
plot(seabed(:,1),seabed(:,2),static_config(:,1),static_config(:,2));
grid on;
legend('seabed','static configuration');
xlim([0 L]);
ylim([-1010 -990]);
xlabel('z [m]');
ylabel('y [m]');

%% POSTER%% 
%plot seabed from VIVANA-analysis in project work + static config 

figure;
%plot(seabed(:,1),seabed(:,2),'LineWidth',2,'Color',[0 0 1]);
%hold on;
area(seabed(:,2),-1010);
hold on;
%area()
plot(static_config(:,1),static_config(:,2),'LineWidth',3,'Color',[0 1 1]);
grid on;
legend('seabed','pipeline');
xlim([0 L]);
ylim([-1010 -990]);
xlabel('z [m]');
ylabel('y [m]');

%% plot
post = 1; 
end
